{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/samtools/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/tabix-cwl:1.3.1"
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "id": "#bgzip.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "baseCommand": "/usr/bin/tabix",
            "arguments": [
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/tabix-cwl:1.3.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.vcf)"
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index.cwl/indexed_vcf"
                }
            ],
            "id": "#index.cwl"
        },
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/indexed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/vcf",
                            "id": "#main/bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip/bgzipped_file"
                    ],
                    "id": "#main/bgzip"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip/bgzipped_file",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
